# PyNumeca
[![Python application](https://github.com/GitMarco27/PyNumeca/actions/workflows/python-app.yml/badge.svg)](https://github.com/GitMarco27/PyNumeca/actions/workflows/python-app.yml)

Python interface to Numera family software
